# Python Wrapper for Trello API

### Installation

```bash
pip install python-trello
```

I use trello a lot for my personal projects, planning and executing them, hence I created my own personal library for common tasks. 

Some use cases

1. Scrape your udemy courses and put them on trello board with checklists for each chapter. 
2. Scrape books from your shelves on goodreads and put them on trello.
3. Scrape details of an apartment search page and put them up on trello.

I just started refactoring a lot of code from two years ago. Things that I should do now:

- [ ] Remove goodreads and udemy code out of this code.
- [ ] Fix tests
- [ ] Update code to use python3 features.
- [ ] Update tests
- [ ] Integrate run scripts for this repo
- [ ] Add pre-commit hooks.
- [ ] Add attrs.